@@ -879,6 +879,6 @@ resetWorkers.default <- function(x, ...) invisible(x)
 resetWorkers.multicore <- function(x, ...) {
   if (usedCores() == 0L) return(invisible(x))
   reg <- sprintf("multicore-%s", session_uuid())
-  FutureRegistry(reg, action = "collect-all", earlySignal = FALSE)
+  FutureRegistry(reg, action = "collect-all")
   stop_if_not(usedCores() == 0L)
 }
